import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{Nn as n,Xn as r}from"./vendor-primevue-D50rA9nL.js";import{ot as i,st as a}from"./vendor-other-BnH5nyVX.js";import{Bo as o,Vo as s,er as c,tr as l}from"./dialogService-Cr3DyAja.js";function useSubscriptionCredits(){let e=s(),{locale:t}=a(),formatBalance=e=>c({cents:e??0,locale:t.value,numberOptions:{minimumFractionDigits:0,maximumFractionDigits:0}});return{totalCredits:r(()=>formatBalance(e.balance?.amount_micros)),monthlyBonusCredits:r(()=>formatBalance(e.balance?.cloud_credit_balance_micros)),prepaidCredits:r(()=>formatBalance(e.balance?.prepaid_balance_micros)),isLoadingBalance:r(()=>e.isFetchingBalance)}}var u=t((()=>{n(),i(),l(),o()}));export{useSubscriptionCredits as n,u as t};
//# sourceMappingURL=useSubscriptionCredits-B5PuEVic.js.map