import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{Bn as n,Cr as r,Mr as i,Nn as a,Xn as o,Zn as s,er as c,sr as l,ui as u,zr as d}from"./vendor-primevue-D50rA9nL.js";var f,p,m,h,g,_,v=t((()=>{a(),f={class:`grid grid-cols-[auto_1fr] gap-x-2 gap-y-1`},p={class:`content-center text-xs text-node-component-slot-text`},m={class:`content-center text-xs text-node-component-slot-text`},h={class:`content-center text-xs text-node-component-slot-text`},g={class:`content-center text-xs text-node-component-slot-text`},_=l({__name:`WidgetBoundingBox`,props:{modelValue:{default:()=>({x:0,y:0,width:512,height:512})},modelModifiers:{}},emits:[`update:modelValue`],setup(e){let t=i(e,`modelValue`),a=o({get:()=>t.value.x,set:e=>{t.value={...t.value,x:e}}}),l=o({get:()=>t.value.y,set:e=>{t.value={...t.value,y:e}}}),_=o({get:()=>t.value.width,set:e=>{t.value={...t.value,width:e}}}),v=o({get:()=>t.value.height,set:e=>{t.value={...t.value,height:e}}});return(e,t)=>(r(),c(`div`,f,[s(`label`,p,u(e.$t(`boundingBox.x`)),1),d(s(`input`,{"onUpdate:modelValue":t[0]||=e=>a.value=e,type:`number`,min:0,step:`1`,class:`h-7 rounded-lg border-none bg-component-node-widget-background px-2 text-xs text-component-node-foreground focus:outline-0`},null,512),[[n,a.value,void 0,{number:!0}]]),s(`label`,m,u(e.$t(`boundingBox.y`)),1),d(s(`input`,{"onUpdate:modelValue":t[1]||=e=>l.value=e,type:`number`,min:0,step:`1`,class:`h-7 rounded-lg border-none bg-component-node-widget-background px-2 text-xs text-component-node-foreground focus:outline-0`},null,512),[[n,l.value,void 0,{number:!0}]]),s(`label`,h,u(e.$t(`boundingBox.width`)),1),d(s(`input`,{"onUpdate:modelValue":t[2]||=e=>_.value=e,type:`number`,min:1,step:`1`,class:`h-7 rounded-lg border-none bg-component-node-widget-background px-2 text-xs text-component-node-foreground focus:outline-0`},null,512),[[n,_.value,void 0,{number:!0}]]),s(`label`,g,u(e.$t(`boundingBox.height`)),1),d(s(`input`,{"onUpdate:modelValue":t[3]||=e=>v.value=e,type:`number`,min:1,step:`1`,class:`h-7 rounded-lg border-none bg-component-node-widget-background px-2 text-xs text-component-node-foreground focus:outline-0`},null,512),[[n,v.value,void 0,{number:!0}]])]))}})})),y,b=t((()=>{v(),v(),y=_}));export{b as n,y as t};
//# sourceMappingURL=WidgetBoundingBox-gArRi3tV.js.map