import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{Cr as n,Nn as r,Zn as i,ai as a,er as o,sr as s}from"./vendor-primevue-D50rA9nL.js";import{En as c,fn as l,rr as u}from"./vendor-other-BnH5nyVX.js";var d,f,p,m=t((()=>{r(),l(),d=[`src`,`alt`],f={key:1,class:`flex size-full items-center justify-center bg-modal-card-placeholder-background`},p=s({__name:`MediaImageTop`,props:{asset:{}},emits:[`image-loaded`,`view`],setup(e,{emit:t}){let r=t,{state:s,error:l,isReady:p}=c({src:e.asset.src??``,alt:e.asset.name});return u(()=>p.value&&s.value?.naturalWidth&&s.value?.naturalHeight,()=>r(`image-loaded`,s.value.naturalWidth,s.value.naturalHeight)),(e,t)=>(n(),o(`div`,{class:`relative size-full overflow-hidden rounded bg-modal-card-placeholder-background`,onDblclick:t[0]||=e=>r(`view`)},[a(l)?(n(),o(`div`,f,t[1]||=[i(`i`,{class:`pi pi-image text-3xl text-muted-foreground`},null,-1)])):(n(),o(`img`,{key:0,src:e.asset.src,alt:e.asset.name,class:`size-full object-contain transition-transform duration-300 group-hover:scale-105 group-data-[selected=true]:scale-105`},null,8,d))],32))}})})),h;t((()=>{m(),m(),h=p}))();export{h as default};
//# sourceMappingURL=MediaImageTop-D9f9GHoc.js.map