import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{ln as n,on as r,sn as i}from"./api-z_dXWY_S.js";function getDistribution(){return i?`ccloud`:`oss`}function buildSupportUrl(e){let t=new URLSearchParams({[a.DISTRIBUTION]:getDistribution()});return e?.userEmail&&(t.append(a.ANONYMOUS_EMAIL,e.userEmail),t.append(a.EMAIL,e.userEmail)),e?.userId&&t.append(a.USER_ID,e.userId),`${o}?${t.toString()}`}var a,o,s=t((()=>{r(),a={DISTRIBUTION:`tf_42243568391700`,ANONYMOUS_EMAIL:`tf_anonymous_requester_email`,EMAIL:`tf_40029135130388`,USER_ID:`tf_42515251051412`},o=`https://support.comfy.org/hc/en-us/requests/new`}));export{s as i,buildSupportUrl as n,getDistribution as r,a as t};
//# sourceMappingURL=config-B6RhrLOM.js.map