const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["./SubscriptionRequiredDialogContent-CkjcaBi_.js","./_plugin-vue_export-helper-Ckv1EJQX.js","./rolldown-runtime-BKYq3fBv.js","./vendor-primevue-D50rA9nL.js","./dialogService-Cr3DyAja.js","./vendor-other-BnH5nyVX.js","./vendor-three-BDtRe4OM.js","./vendor-tiptap-Rj3K7fja.js","./vendor-vue-BAQ5VIVR.js","./vendor-other-CaaUC6Qe.css","./vendor-reka-ui-BivsvaeG.js","./vendor-xterm-ou66y9E9.js","./vendor-xterm-kHJ-D0s7.css","./PanelTemplate-BUPnglF3.js","./api-z_dXWY_S.js","./i18n-ZU7-AXHi.js","./widget-D00AxrDc.js","./colorUtil-CaSrhsxR.js","./tailwindUtil-CORTPblY.js","./Button-DzMg17Os.js","./Slider-DpLALxux.js","./useErrorHandling-Dt_X40fr.js","./remoteConfig-BXkMU0oz.js","./userStore-D0IyjTYG.js","./markdownRendererUtil-DUxQXDfQ.js","./dialogService-ev1tim4K.css","./CloudBadge-z0Hh9VXM.js","./TopbarBadge-DHYqSR1E.js","./SubscribeButton-BB9GpVvD.js","./subscriptionCheckoutUtil-DCWhQWaM.js","./SubscriptionRequiredDialogContent-CiHdewCw.css"])))=>i.map(i=>d[i]);
import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{Nn as n,bn as r,or as i,yn as a}from"./vendor-primevue-D50rA9nL.js";import{ca as o,n as s,sa as c,t as l}from"./dialogService-Cr3DyAja.js";var u,useSubscriptionDialog,d=t((()=>{n(),l(),c(),r(),u=`subscription-required`,useSubscriptionDialog=()=>{let e=s(),t=o();function hide(){t.closeDialog({key:u})}function show(){e.showLayoutDialog({key:u,component:i(()=>a(()=>import(`./SubscriptionRequiredDialogContent-CkjcaBi_.js`),__vite__mapDeps([0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30]),import.meta.url)),props:{onClose:hide},dialogComponentProps:{style:`width: min(1328px, 95vw); max-height: 90vh;`,pt:{root:{class:`rounded-2xl bg-transparent`},content:{class:`!p-0 rounded-2xl border border-border-default bg-base-background/60 backdrop-blur-md shadow-[0_25px_80px_rgba(5,6,12,0.45)]`}}}})}return{show,hide}}}));export{useSubscriptionDialog as n,d as t};
//# sourceMappingURL=useSubscriptionDialog-B0ssUmal.js.map