import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{Cr as n,Mr as r,Nn as i,Xn as a,Zn as o,ai as s,ar as c,er as l,mr as u,n as d,sr as f,t as p}from"./vendor-primevue-D50rA9nL.js";var m,h,g,_=t((()=>{i(),p(),m={class:`flex flex-col gap-1`},h={class:`max-h-[48rem] rounded border p-4`},g=f({__name:`WidgetChart`,props:u({widget:{}},{modelValue:{required:!0},modelModifiers:{}}),emits:[`update:modelValue`],setup(e){let t=r(e,`modelValue`),i=e,u=a(()=>i.widget.options?.type??`line`),f=a(()=>t.value||{labels:[],datasets:[]}),p=a(()=>({responsive:!0,maintainAspectRatio:!1,plugins:{legend:{labels:{color:`#FFF`,usePointStyle:!0,pointStyle:`circle`}}},scales:{x:{ticks:{color:`#9FA2BD`},grid:{display:!0,color:`#9FA2BD`,drawTicks:!1,drawOnChartArea:!0,drawBorder:!1},border:{display:!0,color:`#9FA2BD`}},y:{ticks:{color:`#9FA2BD`},grid:{display:!1,drawTicks:!1,drawOnChartArea:!1,drawBorder:!1},border:{display:!0,color:`#9FA2BD`}}}}));return(e,t)=>(n(),l(`div`,m,[o(`div`,h,[c(s(d),{type:u.value,data:f.value,options:p.value,"aria-label":`${e.widget.name||e.$t(`g.chart`)} - ${u.value} ${e.$t(`g.chartLowercase`)}`},null,8,[`type`,`data`,`options`,`aria-label`])])]))}})})),v;t((()=>{_(),_(),v=g}))();export{v as default};
//# sourceMappingURL=WidgetChart-DV71oBxg.js.map