const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["./i18n-mo7L1SKG.js","./i18n-ZU7-AXHi.js","./vendor-primevue-D50rA9nL.js","./rolldown-runtime-BKYq3fBv.js","./vendor-other-BnH5nyVX.js","./vendor-three-BDtRe4OM.js","./vendor-tiptap-Rj3K7fja.js","./vendor-vue-BAQ5VIVR.js","./vendor-other-CaaUC6Qe.css"])))=>i.map(i=>d[i]);
import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{bn as n,yn as r}from"./vendor-primevue-D50rA9nL.js";import{Xn as i,fn as a,hn as o}from"./vendor-other-BnH5nyVX.js";import{i as s,n as c,r as l}from"./vendor-vue-BAQ5VIVR.js";import{i as u,on as d,r as f,sn as p}from"./api-z_dXWY_S.js";import{Bo as m,Q as h,Vo as g,X as _,co as v,so as y}from"./dialogService-Cr3DyAja.js";import{n as b,t as x}from"./userStore-D0IyjTYG.js";var S,C=t((()=>{a(),l(),d(),y(),_(),u(),m(),x(),n(),S=c(`bootstrap`,()=>{let e=v(),t=h(),{isReady:n,error:a,execute:c}=o(async()=>{let{mergeCustomNodesI18n:e}=await r(async()=>{let{mergeCustomNodesI18n:e}=await import(`./i18n-mo7L1SKG.js`);return{mergeCustomNodesI18n:e}},__vite__mapDeps([0,1,2,3,4,5,6,7,8]),import.meta.url);e(await f.getCustomNodesI18n())},void 0,{immediate:!1}),l=!1;function loadAuthenticatedStores(){l||(l=!0,e.load(),t.loadWorkflows())}async function startStoreBootstrap(){let e=b();if(await e.initialize(),p){let{isInitialized:e}=s(g());await i(e).toBe(!0)}let{needsLogin:t}=s(e);await i(t).toBe(!1),c(),loadAuthenticatedStores()}return{isI18nReady:n,i18nError:a,startStoreBootstrap}})}));export{S as n,C as t};
//# sourceMappingURL=bootstrapStore-l1IJx752.js.map