import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{Cr as n,Nn as r,Qn as i,Xn as a,ai as o,kr as s,sr as c}from"./vendor-primevue-D50rA9nL.js";import{Ao as l,jo as u}from"./dialogService-Cr3DyAja.js";import{n as d,t as f}from"./ComfyQueueButton-CJ-SFhpI.js";import{n as p,t as m}from"./SubscribeToRun-Dxi6gWOg.js";var h,g=t((()=>{r(),d(),p(),l(),h=c({__name:`CloudRunButtonWrapper`,setup(e){let{isActiveSubscription:t}=u(),r=a(()=>t.value?f:m);return(e,a)=>(n(),i(s(r.value),{key:o(t)?`queue`:`subscribe`}))}})})),_;t((()=>{g(),g(),_=h}))();export{_ as default};
//# sourceMappingURL=CloudRunButtonWrapper-Dj5a-bEw.js.map