import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{Cr as n,Er as ee,Gn as r,Nn as i,Rr as a,Zn as o,ai as s,ar as c,er as l,ir as te,sr as u,ui as d}from"./vendor-primevue-D50rA9nL.js";import{ot as f,rn as p,sn as m,st as ne}from"./vendor-other-BnH5nyVX.js";import{r as re,s as h}from"./i18n-ZU7-AXHi.js";import{n as ie,t as ae}from"./Button-DzMg17Os.js";import{n as oe,t as se}from"./_plugin-vue_export-helper-Ckv1EJQX.js";import{n as ce,t as le}from"./GlobalToast-BMy0toxl.js";import{n as g,t as _}from"./BaseViewTemplate-A9dy6oGX.js";var v,y=t((()=>{v=``+new URL(`thumbnail-imMA3y7Z.png`,import.meta.url).href})),b,x=t((()=>{b=``+new URL(`video-BvOHf4P9.mp4`,import.meta.url).href})),S,C=t((()=>{S=``+new URL(`images/comfy-cloud-logo.svg`,import.meta.url).href}));function _sfc_render(e,t){return n(),l(`div`,T,[o(`img`,{src:S,alt:e.$t(`subscription.comfyCloudLogo`),class:`h-3/4 max-h-10 w-auto`},null,8,E)])}var w,T,E,D,ue=t((()=>{i(),C(),oe(),w={},T={class:`mx-auto flex h-[7%] max-h-[70px] w-5/6 items-end`},E=[`alt`],D=se(w,[[`render`,_sfc_render]])})),O,k,A,j,M,N=t((()=>{i(),f(),O={class:`mx-auto flex h-[5%] max-h-[60px] w-5/6 items-start gap-2.5`},k={href:`https://www.comfy.org/terms-of-service`,target:`_blank`,class:`cursor-pointer text-sm text-gray-600 no-underline`},A={href:`https://www.comfy.org/privacy-policy`,target:`_blank`,class:`cursor-pointer text-sm text-gray-600 no-underline`},j={href:`https://support.comfy.org`,class:`cursor-pointer text-sm text-gray-600 no-underline`,target:`_blank`,rel:`noopener noreferrer`},M=u({__name:`CloudTemplateFooter`,setup(e){let{t}=ne();return(e,ee)=>(n(),l(`footer`,O,[o(`a`,k,d(s(t)(`auth.login.termsLink`)),1),o(`a`,A,d(s(t)(`auth.login.privacyLink`)),1),o(`a`,j,d(s(t)(`cloudFooter_needHelp`)),1)]))}})})),P,F=t((()=>{N(),N(),P=M})),I,L,R,z,B,V,H,U,W,G,K,q,J,Y=t((()=>{i(),ie(),re(),y(),x(),ue(),F(),g(),I={class:`flex`},L={class:`relative hidden flex-1 overflow-hidden bg-black lg:block`},R=[`poster`],z=[`src`],B={class:`absolute inset-0 flex items-center justify-center text-center text-white`},V={class:`font-abcrom hero-title font-black uppercase italic`},H={class:`m-2 text-center text-xl text-white`},U={class:`m-0 text-center text-xl text-white`},W={class:`absolute inset-0 flex flex-col justify-end px-14 pb-[64px]`},G={class:`flex items-center justify-end`},K={class:`flex items-center gap-3`},q={class:`text-md text-white`},J=u({__name:`CloudTemplate`,setup(e){let handleDownloadClick=()=>{window.open(`https://www.comfy.org/download`,`_blank`)};return(e,t)=>(n(),l(`div`,I,[c(_,{dark:``,class:`flex-1`},{header:a(()=>[c(D)]),footer:a(()=>[c(P)]),default:a(()=>[ee(e.$slots,`default`)]),_:3}),o(`div`,L,[o(`video`,{class:`absolute inset-0 h-full w-full object-cover`,autoplay:``,muted:``,loop:``,playsinline:``,poster:s(v)},[o(`source`,{src:s(b),type:`video/mp4`},null,8,z)],8,R),t[0]||=o(`div`,{class:`absolute inset-0 h-full w-full bg-black/30`},null,-1),o(`div`,B,[o(`div`,null,[o(`h1`,V,d(s(h)(`cloudStart_title`)),1),o(`p`,H,d(s(h)(`cloudStart_desc`)),1),o(`p`,U,d(s(h)(`cloudStart_explain`)),1)])]),o(`div`,W,[o(`div`,G,[o(`div`,K,[o(`p`,q,d(s(h)(`cloudStart_wantToRun`)),1),c(ae,{type:`button`,class:`h-10 bg-black font-bold text-white`,variant:`secondary`,onClick:handleDownloadClick},{default:a(()=>[te(d(s(h)(`cloudStart_download`)),1)]),_:1})])])])])]))}})})),de=t((()=>{})),X,fe=t((()=>{Y(),Y(),de(),X=J})),Z,Q=t((()=>{i(),m(),ce(),fe(),Z=u({__name:`CloudLayoutView`,setup(e){return(e,t)=>(n(),l(r,null,[c(X,null,{default:a(()=>[c(s(p))]),_:1}),c(le)],64))}})})),$;t((()=>{Q(),Q(),$=Z}))();export{$ as default};
//# sourceMappingURL=CloudLayoutView-Dt81xaBg.js.map