import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{$n as n,Cr as r,Nn as i,Rr as a,Xn as o,ar as s,er as c,hr as l,ir as u,si as d,sr as f,ui as p}from"./vendor-primevue-D50rA9nL.js";import{n as m,t as h}from"./Button-DzMg17Os.js";import{o as g,s as _,t as v}from"./widgetPropFilter-Bp2uptBz.js";var y,b,x=t((()=>{i(),m(),_(),y={class:`flex flex-col gap-1`},b=f({__name:`WidgetButton`,props:{widget:{}},setup(e){let t=e,i=[...v,`iconClass`],f=o(()=>g(t.widget.options,i)),handleClick=()=>{t.widget.callback&&t.widget.callback()};return(e,t)=>(r(),c(`div`,y,[s(h,l({class:`text-base-foreground w-full border-0 bg-component-node-widget-background p-2`,"aria-label":e.widget.label,size:`sm`,variant:`textonly`},f.value,{onClick:handleClick}),{default:a(()=>[u(p(e.widget.label??e.widget.name)+` `,1),e.widget.options?.iconClass?(r(),c(`i`,{key:0,class:d(e.widget.options.iconClass)},null,2)):n(``,!0)]),_:1},16,[`aria-label`])]))}})})),S;t((()=>{x(),x(),S=b}))();export{S as default};
//# sourceMappingURL=WidgetButton-DaK8-fHP.js.map