import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{Nn as n,Xn as r}from"./vendor-primevue-D50rA9nL.js";import{i,n as a}from"./remoteConfig-BXkMU0oz.js";import{r as o,s}from"./i18n-ZU7-AXHi.js";import{_i as c,vi as l}from"./dialogService-Cr3DyAja.js";var u;t((()=>{n(),a(),o(),c(),u=r(()=>{let e=[],t=i.value.server_health_alert;return t&&e.push({text:t.message,label:t.badge,variant:t.severity??`error`,tooltip:t.tooltip}),e.push({label:s(`g.beta`),text:`Comfy Cloud`}),e}),l().registerExtension({name:`Comfy.Cloud.Badges`,get topbarBadges(){return u.value}})}))();
//# sourceMappingURL=cloudBadges-Dpae4k3R.js.map