import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{r as n,s as r}from"./i18n-ZU7-AXHi.js";import{_i as i,vi as a}from"./dialogService-Cr3DyAja.js";import{i as o,r as s,t as c}from"./config-B6RhrLOM.js";var l,u,d,f,p;t((()=>{n(),o(),i(),l=`https://support.comfy.org/hc/en-us/requests/new`,u=`43066738713236`,d=s(),f=`${l}?${new URLSearchParams({ticket_form_id:u,[c.DISTRIBUTION]:d}).toString()}`,p=[{icon:`icon-[lucide--message-circle-question-mark]`,label:r(`actionbar.feedback`),tooltip:r(`actionbar.feedbackTooltip`),onClick:()=>{window.open(f,`_blank`,`noopener,noreferrer`)}}],a().registerExtension({name:`Comfy.Cloud.FeedbackButton`,actionBarButtons:p})}))();
//# sourceMappingURL=cloudFeedbackTopbarButton-DSZcY1kj.js.map