import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{Cr as n,Nn as r,Qn as i,Xn as a,sr as o}from"./vendor-primevue-D50rA9nL.js";import{r as s,s as c}from"./i18n-ZU7-AXHi.js";import{n as l,t as u}from"./TopbarBadge-DHYqSR1E.js";var d,f=t((()=>{r(),s(),l(),d=o({__name:`CloudBadge`,props:{displayMode:{default:`full`},reverseOrder:{type:Boolean,default:!1},noPadding:{type:Boolean,default:!1},backgroundColor:{default:`var(--comfy-menu-bg)`}},setup(e){let t=a(()=>({label:c(`g.beta`),text:`Comfy Cloud`}));return(e,r)=>(n(),i(u,{badge:t.value,"display-mode":e.displayMode,"reverse-order":e.reverseOrder,"no-padding":e.noPadding,"background-color":e.backgroundColor},null,8,[`badge`,`display-mode`,`reverse-order`,`no-padding`,`background-color`]))}})})),p,m=t((()=>{f(),f(),p=d}));export{m as n,p as t};
//# sourceMappingURL=CloudBadge-z0Hh9VXM.js.map