import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{fn as n,nr as r}from"./vendor-other-BnH5nyVX.js";import{Ao as i,_i as a,bo as o,jo as s,vi as c,xo as l}from"./dialogService-Cr3DyAja.js";import{n as u,t as d}from"./refreshRemoteConfig-BEXmhsvN.js";t((()=>{n(),o(),i(),d(),a(),c().registerExtension({name:`Comfy.Cloud.RemoteConfig`,setup:async()=>{let{isLoggedIn:e}=l(),{isActiveSubscription:t}=s();r([e,t],()=>{e.value&&u()},{debounce:256}),setInterval(()=>void u(),6e5)}})}))();
//# sourceMappingURL=cloudRemoteConfig-CL6pBEGY.js.map