import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{Cr as n,Nn as r,Un as i,Zn as a,er as o,sr as s,ui as c}from"./vendor-primevue-D50rA9nL.js";var l,u,d,f,p,m=t((()=>{r(),l={class:`relative size-full overflow-hidden rounded`},u={class:`flex size-full flex-col items-center justify-center gap-2 bg-modal-card-placeholder-background transition-transform duration-300 group-hover:scale-105 group-data-[selected=true]:scale-105`},d={class:`text-base-foreground`},f=[`src`],p=s({__name:`MediaAudioTop`,props:{asset:{}},setup(e){return(e,t)=>(n(),o(`div`,l,[a(`div`,u,[t[1]||=a(`i`,{class:`icon-[lucide--music] text-3xl text-base-foreground`},null,-1),a(`span`,d,c(e.$t(`assetBrowser.media.audioPlaceholder`)),1)]),a(`audio`,{controls:``,class:`absolute bottom-0 left-0 w-full p-2`,src:e.asset.src,onClick:t[0]||=i(()=>{},[`stop`])},null,8,f)]))}})})),h;t((()=>{m(),m(),h=p}))();export{h as default};
//# sourceMappingURL=MediaAudioTop-p1BUsZbd.js.map