import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{Fr as n,Nn as r}from"./vendor-primevue-D50rA9nL.js";import{Ao as i,_i as a,bo as o,jo as s,vi as c,xo as l}from"./dialogService-Cr3DyAja.js";t((()=>{r(),o(),i(),a(),c().registerExtension({name:`Comfy.Cloud.Subscription`,setup:async()=>{let{isLoggedIn:e}=l(),{requireActiveSubscription:t}=s(),checkSubscriptionStatus=()=>{e.value&&t()};n(()=>e.value,checkSubscriptionStatus,{immediate:!0})}})}))();
//# sourceMappingURL=cloudSubscription-BS40_7Aa.js.map