import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{$n as n,Cr as r,Er as i,Nn as a,Qn as o,Rr as s,ai as c,er as l,si as u,sr as d}from"./vendor-primevue-D50rA9nL.js";import{$ as f,et as p}from"./vendor-other-BnH5nyVX.js";import{O as m,t as h}from"./vendor-reka-ui-BivsvaeG.js";import{n as g,t as _}from"./tailwindUtil-CORTPblY.js";var v,y=t((()=>{p(),v=f({base:`relative inline-flex items-center justify-center gap-2 cursor-pointer whitespace-nowrap appearance-none border-none rounded-md text-sm font-medium font-inter transition-colors focus-visible:outline-none focus-visible:ring-1 focus-visible:ring-ring disabled:pointer-events-none disabled:opacity-50 [&_svg]:pointer-events-none [&_svg]:size-4 [&_svg]:shrink-0`,variants:{variant:{secondary:`bg-secondary-background text-secondary-foreground hover:bg-secondary-background-hover`,primary:`bg-primary-background text-base-foreground hover:bg-primary-background-hover`,inverted:`bg-base-foreground text-base-background hover:bg-base-foreground/80`,destructive:`bg-destructive-background text-base-foreground hover:bg-destructive-background-hover`,textonly:`text-base-foreground bg-transparent hover:bg-secondary-background-hover`,"muted-textonly":`text-muted-foreground bg-transparent hover:bg-secondary-background-hover`,"destructive-textonly":`text-destructive-background bg-transparent hover:bg-destructive-background/10`,"overlay-white":`bg-white text-gray-600 hover:bg-white/90`},size:{sm:`h-6 rounded-sm px-2 py-1 text-xs`,md:`h-8 rounded-lg p-2 text-xs`,lg:`h-10 rounded-lg px-4 py-2 text-sm`,icon:`size-8`,"icon-sm":`size-5 p-0`,unset:``}},defaultVariants:{variant:`secondary`,size:`md`}})})),b,x,S=t((()=>{a(),h(),_(),y(),b={key:0,class:`pi pi-spin pi-spinner`},x=d({__name:`Button`,props:{variant:{},size:{},class:{default:``},loading:{type:Boolean,default:!1},disabled:{type:Boolean,default:!1},asChild:{type:Boolean},as:{default:`button`}},setup(e){return(t,a)=>(r(),o(c(m),{as:t.as,"as-child":t.asChild,disabled:t.disabled||t.loading,class:u(c(g)(c(v)({variant:t.variant,size:t.size}),e.class))},{default:s(()=>[t.loading?(r(),l(`i`,b)):n(``,!0),t.loading?n(``,!0):i(t.$slots,`default`,{key:1})]),_:3},8,[`as`,`as-child`,`disabled`,`class`]))}})})),C,w=t((()=>{S(),S(),C=x}));export{y as i,w as n,v as r,C as t};
//# sourceMappingURL=Button-DzMg17Os.js.map