import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{Nn as n,ai as r}from"./vendor-primevue-D50rA9nL.js";import{X as i,ot as a}from"./api-z_dXWY_S.js";var isNodeMissingDefinition,collectMissingNodes,graphHasMissingNodes,o=t((()=>{n(),a(),isNodeMissingDefinition=(e,t)=>{let n=e?.type;return n?!t[n]:!1},collectMissingNodes=(e,t)=>{if(!e)return[];let n=r(t);return i(e,e=>isNodeMissingDefinition(e,n))},graphHasMissingNodes=(e,t)=>collectMissingNodes(e,t).length>0}));export{o as n,graphHasMissingNodes as t};
//# sourceMappingURL=graphHasMissingNodes-DpSgWfC3.js.map