import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{Nn as n,Xn as r,Xr as i}from"./vendor-primevue-D50rA9nL.js";function configValueOrDefault(e,t,n){return e[t]||n}var a,o,s,c=t((()=>{n(),a=i(`unloaded`),o=r(()=>a.value===`authenticated`),s=i({})}));export{a,s as i,c as n,o as r,configValueOrDefault as t};
//# sourceMappingURL=remoteConfig-BXkMU0oz.js.map