import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{$n as n,Cr as r,Gn as i,Nn as a,Rr as o,Tr as s,Xr as c,Zn as l,ar as u,er as d,ir as f,si as p,sr as m,ui as h}from"./vendor-primevue-D50rA9nL.js";import{ln as g,sn as _}from"./vendor-other-BnH5nyVX.js";import{n as v,t as y}from"./Button-DzMg17Os.js";import{Oo as b,ko as x}from"./dialogService-Cr3DyAja.js";var S,C,w,T,E,D,O,k,A,j,M,N,P,F=t((()=>{a(),_(),v(),b(),S={class:`flex h-full items-center justify-center p-6`},C={class:`max-w-[100vw] text-center lg:w-[500px]`},w={class:`mb-3 text-xl text-text-primary`},T={class:`mb-5 text-muted`},E={class:`mb-4 rounded bg-secondary-background px-3 py-2 text-left`},D={class:`mb-2 text-sm font-semibold text-text-primary`},O={class:`space-y-1.5 text-sm text-muted`},k={key:0,class:`mb-4 text-left`},A={key:0,class:`mt-2 rounded border-muted-background border p-4 font-mono text-xs text-muted-foreground break-all`},j={class:`mb-5 text-center text-sm text-gray-600`},M={href:`https://support.comfy.org`,class:`cursor-pointer text-blue-400 no-underline`,target:`_blank`,rel:`noopener noreferrer`},N={class:`flex flex-col gap-3`},P=m({__name:`CloudAuthTimeoutView`,props:{errorMessage:{}},setup(e){let t=g(),{logout:a}=x(),m=c(!1),handleRestart=async()=>{await a(),await t.replace({name:`cloud-login`})};return(e,t)=>(r(),d(`div`,S,[l(`div`,C,[l(`h2`,w,h(e.$t(`cloudOnboarding.authTimeout.title`)),1),l(`p`,T,h(e.$t(`cloudOnboarding.authTimeout.message`)),1),l(`div`,E,[l(`h3`,D,h(e.$t(`cloudOnboarding.authTimeout.troubleshooting`)),1),l(`ul`,O,[(r(!0),d(i,null,s(e.$tm(`cloudOnboarding.authTimeout.causes`),(e,n)=>(r(),d(`li`,{key:n,class:`flex gap-2`},[t[1]||=l(`span`,null,`•`,-1),l(`span`,null,h(e),1)]))),128))])]),e.errorMessage?(r(),d(`div`,k,[l(`button`,{class:`flex w-full items-center justify-between rounded bg-secondary-background px-4 py-2 text-sm text-text-secondary transition-colors hover:bg-secondary-background-hover border-0`,onClick:t[0]||=e=>m.value=!m.value},[l(`span`,null,h(e.$t(`cloudOnboarding.authTimeout.technicalDetails`)),1),l(`i`,{class:p([`pi`,m.value?`pi-chevron-up`:`pi-chevron-down`])},null,2)]),m.value?(r(),d(`div`,A,h(e.errorMessage),1)):n(``,!0)])):n(``,!0),l(`p`,j,[f(h(e.$t(`cloudOnboarding.authTimeout.helpText`))+` `,1),l(`a`,M,h(e.$t(`cloudOnboarding.authTimeout.supportLink`)),1),t[2]||=f(`. `)]),l(`div`,N,[u(y,{class:`w-full`,onClick:handleRestart},{default:o(()=>[f(h(e.$t(`cloudOnboarding.authTimeout.restart`)),1)]),_:1})])])]))}})})),I;t((()=>{F(),F(),I=P}))();export{I as default};
//# sourceMappingURL=CloudAuthTimeoutView-CQcIJUV9.js.map