import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{Cr as n,Nn as r,Or as i,Qn as a,Rr as o,Xn as s,Zn as c,ir as l,sr as u,ui as d,zr as f}from"./vendor-primevue-D50rA9nL.js";import{fn as p,gn as m,ot as h,st as g,un as _}from"./vendor-other-BnH5nyVX.js";import{on as v,sn as y}from"./api-z_dXWY_S.js";import{n as b,t as x}from"./Button-DzMg17Os.js";import{Ao as S,in as C,jo as w,rn as T}from"./dialogService-Cr3DyAja.js";var E,D=t((()=>{r(),p(),h(),b(),S(),v(),T(),E=u({__name:`SubscribeToRun`,setup(e){let{t}=g(),r=m(_).greaterOrEqual(`md`),u=s(()=>r.value?t(`subscription.subscribeToRunFull`):t(`subscription.subscribeToRun`)),{showSubscriptionDialog:p}=w(),handleSubscribeToRun=()=>{y&&C()?.trackRunButton({subscribe_to_run:!0}),p()};return(e,t)=>{let r=i(`tooltip`);return f((n(),a(x,{class:`subscribe-to-run-button whitespace-nowrap`,variant:`primary`,size:`sm`,style:{background:`var(--color-subscription-button-gradient)`,color:`var(--color-white)`,borderColor:`transparent`},"data-testid":`subscribe-to-run-button`,onClick:handleSubscribeToRun},{default:o(()=>[t[0]||=c(`i`,{class:`pi pi-lock`},null,-1),l(` `+d(u.value),1)]),_:1})),[[r,{value:e.$t(`subscription.subscribeToRunFull`),showDelay:600},void 0,{bottom:!0}]])}}})})),O,k=t((()=>{D(),D(),O=E}));export{k as n,O as t};
//# sourceMappingURL=SubscribeToRun-Dxi6gWOg.js.map