import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{at as n,it as r}from"./dialogService-Cr3DyAja.js";function formatTime(e){return isNaN(e)||e===0?`0:00`:`${Math.floor(e/60)}:${Math.floor(e%60).toString().padStart(2,`0`)}`}function getResourceURL(e,t,n=`input`){return`/view?${[`filename=`+encodeURIComponent(t),`type=`+n,`subfolder=`+e,r.getRandParam().substring(1)].join(`&`)}`}function splitFilePath(e){let t=e.lastIndexOf(`/`);return t===-1?[``,e]:[e.substring(0,t),e.substring(t+1)]}var i=t((()=>{n()}));export{splitFilePath as i,getResourceURL as n,i as r,formatTime as t};
//# sourceMappingURL=audioUtils-DTMOZWeY.js.map