import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";function filterWidgetProps(e,t){if(!e)return{};let n={};for(let[r,i]of Object.entries(e))t.includes(r)||(n[r]=i);return n}var n,r,i,a,o,s=t((()=>{n=[`style`,`class`,`dt`,`pt`,`ptOptions`,`unstyled`],r=[...n,`inputClass`,`inputStyle`],i=[...n,`panelClass`,`panelStyle`,`overlayClass`],a=[...n,`thumbnailsPosition`,`verticalThumbnailViewPortHeight`,`indicatorsPosition`,`maskClass`,`containerStyle`,`containerClass`,`galleriaClass`],o=[...n,`badgeClass`]}));export{n as a,i,a as n,filterWidgetProps as o,r,s,o as t};
//# sourceMappingURL=widgetPropFilter-Bp2uptBz.js.map