import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{it as n,nt as r,rt as i,tt as a}from"./vendor-other-BnH5nyVX.js";function cn(...e){return r(i(e))}var o=t((()=>{n(),a()})),s=t((()=>{o()}));export{cn as n,o as r,s as t};
//# sourceMappingURL=tailwindUtil-CORTPblY.js.map