import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{Cr as n,Nn as r,Zn as i,ai as a,er as o,sr as s,ui as c}from"./vendor-primevue-D50rA9nL.js";import{ot as l,st as u}from"./vendor-other-BnH5nyVX.js";import{n as d,t as f}from"./_plugin-vue_export-helper-Ckv1EJQX.js";var p,m,h=t((()=>{r(),l(),p={class:`cloud-sorry-contact-support`},m=s({__name:`CloudSorryContactSupportView`,setup(e){let{t}=u();return(e,r)=>(n(),o(`div`,p,[i(`h1`,null,c(a(t)(`cloudSorryContactSupport_title`)),1)]))}})})),g=t((()=>{})),_;t((()=>{h(),h(),g(),d(),_=f(m,[[`__scopeId`,`data-v-c3fa108d`]])}))();export{_ as default};
//# sourceMappingURL=CloudSorryContactSupportView-CQgwqrIY.js.map