import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{Cr as n,Gn as r,Nn as i,Qn as a,Rr as o,Tr as s,Xr as c,ai as l,ar as u,er as d,hr as f,si as p,sr as m}from"./vendor-primevue-D50rA9nL.js";import{Gn as h,fn as g}from"./vendor-other-BnH5nyVX.js";import{c as _,k as v,l as y,s as b,t as x,u as S}from"./vendor-reka-ui-BivsvaeG.js";import{n as C,t as w}from"./tailwindUtil-CORTPblY.js";var T,E=t((()=>{i(),g(),x(),w(),T=m({__name:`Slider`,props:{defaultValue:{},modelValue:{},disabled:{type:Boolean},orientation:{},dir:{},inverted:{type:Boolean},min:{},max:{},step:{},minStepsBetweenThumbs:{},thumbAlignment:{},asChild:{type:Boolean},as:{},name:{},required:{type:Boolean},class:{}},emits:[`update:modelValue`,`valueCommit`],setup(e,{emit:t}){let i=e,m=c(!1),setPressed=e=>{m.value=e},g=t,x=v(h(i,`class`),g);return(e,t)=>(n(),a(l(S),f({"data-slot":`slider`,class:l(C)(`relative flex w-full touch-none items-center select-none data-[disabled]:opacity-50`,`data-[orientation=vertical]:h-full data-[orientation=vertical]:min-h-44 data-[orientation=vertical]:w-auto data-[orientation=vertical]:flex-col`,i.class)},l(x),{onSlideStart:t[0]||=()=>setPressed(!0),onSlideMove:t[1]||=()=>setPressed(!0),onSlideEnd:t[2]||=()=>setPressed(!1)}),{default:o(({modelValue:e})=>[u(l(b),{"data-slot":`slider-track`,class:p(l(C)(`bg-node-stroke relative grow overflow-hidden rounded-full`,`cursor-pointer overflow-visible`,`before:absolute before:-inset-2 before:block before:bg-transparent`,`data-[orientation=horizontal]:h-0.5 data-[orientation=horizontal]:w-full`,`data-[orientation=vertical]:h-full data-[orientation=vertical]:w-0.5`))},{default:o(()=>[u(l(y),{"data-slot":`slider-range`,class:`absolute bg-node-component-surface-highlight data-[orientation=horizontal]:h-full data-[orientation=vertical]:w-full`})]),_:1},8,[`class`]),(n(!0),d(r,null,s(e,(e,t)=>(n(),a(l(_),{key:t,"data-slot":`slider-thumb`,class:p(l(C)(`bg-node-component-surface-highlight ring-node-component-surface-selected block size-3.5 shrink-0 rounded-full shadow-sm transition-[color,box-shadow]`,`cursor-grab`,`before:absolute before:-inset-1 before:block before:bg-transparent before:rounded-full`,`hover:ring-2 focus-visible:ring-2 focus-visible:outline-hidden disabled:pointer-events-none disabled:opacity-50`,{"cursor-grabbing":m.value}))},null,8,[`class`]))),128))]),_:1},16,[`class`]))}})})),D,O=t((()=>{E(),E(),D=T}));export{O as n,D as t};
//# sourceMappingURL=Slider-DpLALxux.js.map