import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{Cr as n,Er as r,Nn as i,Vn as a,Xr as o,Zn as s,ai as c,br as l,er as u,gr as d,si as f,sr as p,zr as m}from"./vendor-primevue-D50rA9nL.js";import{dn as h,fn as g,pn as _,un as v}from"./api-z_dXWY_S.js";var y,b,x=t((()=>{i(),h(),y={class:`flex w-full grow items-center justify-center overflow-auto`},b=p({__name:`BaseViewTemplate`,props:{dark:{type:Boolean,default:!1}},setup(e){let t={color:`rgba(0, 0, 0, 0)`,symbolColor:`#d4d4d4`},i={color:`rgba(0, 0, 0, 0)`,symbolColor:`#171717`},p=o(null);return l(async()=>{g()&&(await d(),v().changeTheme({...e.dark?t:i,height:p.value?.getBoundingClientRect().height??0}))}),(e,t)=>(n(),u(`div`,{class:f([`flex h-svh w-screen flex-col font-sans`,[e.dark?`dark-theme bg-neutral-900 text-neutral-300`:`bg-neutral-300 text-neutral-900`]])},[m(s(`div`,{ref_key:`topMenuRef`,ref:p,class:`app-drag h-(--comfy-topbar-height) w-full`},null,512),[[a,c(_)()]]),s(`div`,y,[r(e.$slots,`default`)])],2))}})})),S,C=t((()=>{x(),x(),S=b}));export{C as n,S as t};
//# sourceMappingURL=BaseViewTemplate-A9dy6oGX.js.map