import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{$n as n,Cr as r,Er as i,Gn as a,Nn as o,Un as s,Zn as c,ai as l,er as u,fr as d,ir as f,si as p,sr as m,ui as h}from"./vendor-primevue-D50rA9nL.js";import{n as g,t as _}from"./tailwindUtil-CORTPblY.js";var v,y,b,x,S=t((()=>{o(),_(),v={class:`grid grid-cols-subgrid min-w-0 justify-between gap-1 text-node-component-slot-text`},y={key:0,class:`truncate content-center-safe`},b={class:`relative min-w-0 flex-1`},x=m({__name:`WidgetLayoutField`,props:{widget:{}},setup(e){let t=d(`hideLayoutField`,!1);return(e,o)=>(r(),u(`div`,v,[l(t)?n(``,!0):(r(),u(`div`,y,[e.widget.name?(r(),u(a,{key:0},[f(h(e.widget.label||e.widget.name),1)],64)):n(``,!0)])),c(`div`,b,[c(`div`,{class:p(l(g)(`cursor-default min-w-0 rounded-lg focus-within:ring focus-within:ring-component-node-widget-background-highlighted transition-all`,e.widget.borderStyle)),onPointerdown:o[0]||=s(()=>{},[`stop`]),onPointermove:o[1]||=s(()=>{},[`stop`]),onPointerup:o[2]||=s(()=>{},[`stop`])},[i(e.$slots,`default`)],34)])]))}})})),C,w=t((()=>{S(),S(),C=x}));export{w as n,C as t};
//# sourceMappingURL=WidgetLayoutField-DevzxXMh.js.map