import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{Cr as n,Nn as r,Xn as i,Xr as a,Zn as o,er as s,sr as c,ui as l}from"./vendor-primevue-D50rA9nL.js";var u,d,f,p,m,h=t((()=>{r(),u={class:`relative size-full overflow-hidden rounded`},d=[`src`,`alt`],f={key:1,class:`flex size-full flex-col items-center justify-center gap-2 bg-modal-card-placeholder-background transition-transform duration-300 group-hover:scale-105 group-data-[selected=true]:scale-105`},p={class:`text-sm text-base-foreground`},m=c({__name:`Media3DTop`,props:{asset:{}},setup(e){let t=a(!1),r=i(()=>e.asset?.src?e.asset.src.replace(/([?&]filename=)([^&]*)/,`$1$2.png`):``);return(e,i)=>(n(),s(`div`,u,[t.value?(n(),s(`div`,f,[i[1]||=o(`i`,{class:`icon-[lucide--box] text-3xl text-muted-foreground`},null,-1),o(`span`,p,l(e.$t(`assetBrowser.media.threeDModelPlaceholder`)),1)])):(n(),s(`img`,{key:0,src:r.value,alt:e.asset?.name,class:`size-full object-contain transition-transform duration-300 group-hover:scale-105 group-data-[selected=true]:scale-105`,onError:i[0]||=e=>t.value=!0},null,40,d))]))}})})),g;t((()=>{h(),h(),g=m}))();export{g as default};
//# sourceMappingURL=Media3DTop-DT1cFo83.js.map