import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{Cr as n,Dt as r,Nn as i,Ot as a,Qn as o,Xn as s,Xr as c,ai as l,sr as u}from"./vendor-primevue-D50rA9nL.js";var d,f=t((()=>{i(),r(),d=u({__name:`UserAvatar`,props:{photoUrl:{},ariaLabel:{}},setup(e){let t=c(!1),handleImageError=()=>{t.value=!0},r=s(()=>e.photoUrl&&!t.value);return(e,t)=>(n(),o(l(a),{class:`bg-interface-panel-selected-surface`,image:e.photoUrl??void 0,icon:r.value?void 0:`icon-[lucide--user]`,"pt:icon:class":{"size-4":!r.value},shape:`circle`,"aria-label":e.ariaLabel??e.$t(`auth.login.userAvatar`),onError:handleImageError},null,8,[`image`,`icon`,`pt:icon:class`,`aria-label`]))}})})),p,m=t((()=>{f(),f(),p=d}));export{m as n,p as t};
//# sourceMappingURL=UserAvatar-BviPpgVy.js.map