import{n as e}from"./rolldown-runtime-BKYq3fBv.js";import{r as t,s as n}from"./i18n-ZU7-AXHi.js";import{_i as r,vi as i}from"./dialogService-Cr3DyAja.js";var a;e((()=>{t(),r(),a=[{text:n(`nightly.badge.label`),label:n(`g.nightly`),variant:`warning`,tooltip:n(`nightly.badge.tooltip`)}],i().registerExtension({name:`Comfy.Nightly.Badges`,topbarBadges:a})}))();
//# sourceMappingURL=nightlyBadges-IgZabzjk.js.map