import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{Cr as n,Mr as r,Nn as i,Qn as a,Rr as o,Xn as s,ai as c,an as l,ar as u,hr as d,mr as f,on as p,sr as m}from"./vendor-primevue-D50rA9nL.js";import{n as h,t as g}from"./tailwindUtil-CORTPblY.js";import{o as _,r as v,s as y}from"./widgetPropFilter-Bp2uptBz.js";import{n as b,t as x}from"./layout-HATgRrPk.js";import{n as S,t as C}from"./WidgetLayoutField-DevzxXMh.js";var w,T=t((()=>{i(),l(),g(),y(),b(),S(),w=m({__name:`WidgetInputText`,props:f({widget:{}},{modelValue:{default:``},modelModifiers:{}}),emits:[`update:modelValue`],setup(e){let t=e,i=r(e,`modelValue`),l=s(()=>_(t.widget.options,v));return(e,t)=>(n(),a(C,{widget:e.widget},{default:o(()=>[u(c(p),d({modelValue:i.value,"onUpdate:modelValue":t[0]||=e=>i.value=e},l.value,{class:c(h)(c(x),`w-full text-xs py-2 px-4`),"aria-label":e.widget.name,size:`small`,pt:{root:`truncate min-w-[4ch]`}}),null,16,[`modelValue`,`class`,`aria-label`])]),_:1},8,[`widget`]))}})})),E;t((()=>{T(),T(),E=w}))();export{E as default};
//# sourceMappingURL=WidgetInputText-DP8QOfqW.js.map