import{i as e,n as t}from"./rolldown-runtime-BKYq3fBv.js";import{Cr as n,Mr as r,Nn as i,Qn as a,Rr as o,Un as s,Xn as c,Zn as l,ai as u,ar as d,at as f,hr as p,jr as m,m as h,mr as g,ot as _,p as v,si as y,sr as b,ui as x}from"./vendor-primevue-D50rA9nL.js";import{n as S,t as C}from"./tailwindUtil-CORTPblY.js";import{o as w,r as T,s as E}from"./widgetPropFilter-Bp2uptBz.js";import{n as D,t as O}from"./layout-HATgRrPk.js";var k,A,j=t((()=>{i(),f(),v(),C(),E(),D(),k=[`for`],A=b({__name:`WidgetTextarea`,props:g({widget:{},placeholder:{default:``}},{modelValue:{default:``},modelModifiers:{}}),emits:[`update:modelValue`],setup(e){let t=r(e,`modelValue`),i=c(()=>w(e.widget.options,T)),f=c(()=>e.widget.label||e.widget.name),g=m();return(e,r)=>(n(),a(u(_),{variant:`in`,class:y(u(S)(`rounded-lg space-y-1 focus-within:ring focus-within:ring-component-node-widget-background-highlighted transition-all`,e.widget.borderStyle))},{default:o(()=>[d(u(h),p(i.value,{id:u(g),modelValue:t.value,"onUpdate:modelValue":r[0]||=e=>t.value=e,class:u(S)(u(O),`size-full text-xs resize-none`),placeholder:e.placeholder,readonly:e.widget.options?.read_only,disabled:e.widget.options?.read_only,fluid:``,"data-capture-wheel":`true`,onPointerdownCapture:r[1]||=s(()=>{},[`stop`]),onPointermoveCapture:r[2]||=s(()=>{},[`stop`]),onPointerupCapture:r[3]||=s(()=>{},[`stop`]),onContextmenuCapture:r[4]||=s(()=>{},[`stop`])}),null,16,[`id`,`modelValue`,`class`,`placeholder`,`readonly`,`disabled`]),l(`label`,{for:u(g)},x(f.value),9,k)]),_:1},8,[`class`]))}})})),M;t((()=>{j(),j(),M=A}))();export{M as default};
//# sourceMappingURL=WidgetTextarea-DTmMNKb3.js.map